"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

from builtins import (
    int,
)
from google.protobuf.descriptor import (
    Descriptor,
    FileDescriptor,
)
from google.protobuf.message import (
    Message,
)
from typing import (
    Literal,
    final,
)

DESCRIPTOR: FileDescriptor

@final
class Ping(Message):
    DESCRIPTOR: Descriptor

    A_FIELD_NUMBER: int
    B_FIELD_NUMBER: int
    a: int
    b: int
    def __init__(
        self,
        *,
        a: int = ...,
        b: int = ...,
    ) -> None: ...
    def ClearField(self, field_name: Literal["a", b"a", "b", b"b"]) -> None: ...

@final
class Pong(Message):
    DESCRIPTOR: Descriptor

    C_FIELD_NUMBER: int
    c: int
    def __init__(
        self,
        *,
        c: int = ...,
    ) -> None: ...
    def ClearField(self, field_name: Literal["c", b"c"]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

from builtins import (
    int,
)
from collections.abc import (
    Iterable,
)
from fr24.proto._common_pb2 import (
    RadarHistoryRecord,
)
from google.protobuf.descriptor import (
    Descriptor,
    FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer,
)
from google.protobuf.message import (
    Message,
)
from typing import (
    Literal,
    final,
)

DESCRIPTOR: FileDescriptor

@final
class LiveTrailRequest(Message):
    DESCRIPTOR: Descriptor

    FLIGHT_ID_FIELD_NUMBER: int
    flight_id: int
    def __init__(
        self,
        *,
        flight_id: int = ...,
    ) -> None: ...
    def ClearField(self, field_name: Literal["flight_id", b"flight_id"]) -> None: ...

@final
class LiveTrailResponse(Message):
    DESCRIPTOR: Descriptor

    RADAR_RECORDS_LIST_FIELD_NUMBER: int
    @property
    def radar_records_list(self) -> RepeatedCompositeFieldContainer[RadarHistoryRecord]:
        """?"""

    def __init__(
        self,
        *,
        radar_records_list: Iterable[RadarHistoryRecord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: Literal["radar_records_list", b"radar_records_list"]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

from builtins import (
    int,
    str,
)
from collections.abc import (
    Iterable,
)
from google.protobuf.descriptor import (
    Descriptor,
    FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer,
)
from google.protobuf.message import (
    Message,
)
from typing import (
    Literal,
    final,
)

DESCRIPTOR: FileDescriptor

@final
class FollowedFlight(Message):
    DESCRIPTOR: Descriptor

    FLIGHT_ID_FIELD_NUMBER: int
    LIVE_CLICKS_FIELD_NUMBER: int
    TOTAL_CLICKS_FIELD_NUMBER: int
    FLIGHT_NUMBER_FIELD_NUMBER: int
    CALLSIGN_FIELD_NUMBER: int
    SQUAWK_FIELD_NUMBER: int
    FROM_IATA_FIELD_NUMBER: int
    FROM_CITY_FIELD_NUMBER: int
    TO_IATA_FIELD_NUMBER: int
    TO_CITY_FIELD_NUMBER: int
    TYPE_FIELD_NUMBER: int
    FULL_DESCRIPTION_FIELD_NUMBER: int
    flight_id: int
    """FR24 Flight ID (e.g. `962709904` = `0x3961c990`)"""
    live_clicks: int
    """Number of live clicks/views (e.g. `1212`)"""
    total_clicks: int
    """Total number of clicks/views (e.g. `6128`)"""
    flight_number: str
    """Flight number (e.g. `"EK261"`)"""
    callsign: str
    """Callsign (e.g. `"UAE261"`)"""
    squawk: int
    """Squawk code (e.g. `4032` = `0o7700`)"""
    from_iata: str
    """IATA code of origin airport (e.g. `"DXB"`)"""
    from_city: str
    """City name of origin airport (e.g. `"Dubai"`)"""
    to_iata: str
    """IATA code of destination airport (e.g. `"GRU"`)"""
    to_city: str
    """City name of destination airport (e.g. `"Sao Paulo"`)"""
    type: str
    """Aircraft type code (e.g. `"A388"`)"""
    full_description: str
    """Full aircraft description (e.g. `"Airbus A380-861"`)"""
    def __init__(
        self,
        *,
        flight_id: int = ...,
        live_clicks: int = ...,
        total_clicks: int = ...,
        flight_number: str = ...,
        callsign: str = ...,
        squawk: int = ...,
        from_iata: str = ...,
        from_city: str = ...,
        to_iata: str = ...,
        to_city: str = ...,
        type: str = ...,
        full_description: str = ...,
    ) -> None: ...
    def ClearField(self, field_name: Literal["callsign", b"callsign", "flight_id", b"flight_id", "flight_number", b"flight_number", "from_city", b"from_city", "from_iata", b"from_iata", "full_description", b"full_description", "live_clicks", b"live_clicks", "squawk", b"squawk", "to_city", b"to_city", "to_iata", b"to_iata", "total_clicks", b"total_clicks", "type", b"type"]) -> None: ...

@final
class TopFlightsRequest(Message):
    DESCRIPTOR: Descriptor

    LIMIT_FIELD_NUMBER: int
    limit: int
    """1..=10"""
    def __init__(
        self,
        *,
        limit: int = ...,
    ) -> None: ...
    def ClearField(self, field_name: Literal["limit", b"limit"]) -> None: ...

@final
class TopFlightsResponse(Message):
    DESCRIPTOR: Descriptor

    SCOREBOARD_LIST_FIELD_NUMBER: int
    @property
    def scoreboard_list(self) -> RepeatedCompositeFieldContainer[FollowedFlight]: ...
    def __init__(
        self,
        *,
        scoreboard_list: Iterable[FollowedFlight] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: Literal["scoreboard_list", b"scoreboard_list"]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

from builtins import (
    bool,
    int,
)
from collections.abc import (
    Iterable,
)
from fr24.proto._common_pb2 import (
    AircraftInfo,
    DelayStatus,
    ExtendedFlightInfo,
    FlightPlan,
    FlightProgress,
    FlightStage,
    PositionBuffer,
    RestrictionVisibility,
    ScheduleInfo,
    TrailPoint,
)
from google.protobuf.descriptor import (
    Descriptor,
    FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer,
)
from google.protobuf.message import (
    Message,
)
from typing import (
    Literal,
    final,
)

DESCRIPTOR: FileDescriptor

@final
class FlightProgress(Message):
    DESCRIPTOR: Descriptor

    TRAVERSED_DISTANCE_FIELD_NUMBER: int
    REMAINING_DISTANCE_FIELD_NUMBER: int
    ELAPSED_TIME_FIELD_NUMBER: int
    REMAINING_TIME_FIELD_NUMBER: int
    ETA_FIELD_NUMBER: int
    GREAT_CIRCLE_DISTANCE_FIELD_NUMBER: int
    MEAN_FLIGHT_TIME_FIELD_NUMBER: int
    FLIGHT_STAGE_FIELD_NUMBER: int
    DELAY_STATUS_FIELD_NUMBER: int
    PROGRESS_PCT_FIELD_NUMBER: int
    traversed_distance: int
    """Distance traversed, meters"""
    remaining_distance: int
    """Distance remaining, meters"""
    elapsed_time: int
    """Elapsed time since departure, seconds"""
    remaining_time: int
    """Remaining time until arrival, seconds"""
    eta: int
    """Estimated time of arrival, Unix timestamp in seconds"""
    great_circle_distance: int
    """Great circle distance, meters"""
    mean_flight_time: int
    """Mean flight time, seconds"""
    flight_stage: FlightStage.ValueType
    delay_status: DelayStatus.ValueType
    progress_pct: int
    """Progress percentage of the flight (0-100)"""
    def __init__(
        self,
        *,
        traversed_distance: int = ...,
        remaining_distance: int = ...,
        elapsed_time: int = ...,
        remaining_time: int = ...,
        eta: int = ...,
        great_circle_distance: int = ...,
        mean_flight_time: int = ...,
        flight_stage: FlightStage.ValueType = ...,
        delay_status: DelayStatus.ValueType = ...,
        progress_pct: int = ...,
    ) -> None: ...
    def ClearField(self, field_name: Literal["delay_status", b"delay_status", "elapsed_time", b"elapsed_time", "eta", b"eta", "flight_stage", b"flight_stage", "great_circle_distance", b"great_circle_distance", "mean_flight_time", b"mean_flight_time", "progress_pct", b"progress_pct", "remaining_distance", b"remaining_distance", "remaining_time", b"remaining_time", "traversed_distance", b"traversed_distance"]) -> None: ...

@final
class FlightDetailsRequest(Message):
    DESCRIPTOR: Descriptor

    FLIGHT_ID_FIELD_NUMBER: int
    RESTRICTION_MODE_FIELD_NUMBER: int
    VERBOSE_FIELD_NUMBER: int
    flight_id: int
    """FR24 Flight ID (e.g. `962788562` = `0x3962fcd2`)"""
    restriction_mode: RestrictionVisibility.ValueType
    verbose: bool
    """Whether to include `flight_plan` and `flight_trail_list` in the response"""
    def __init__(
        self,
        *,
        flight_id: int = ...,
        restriction_mode: RestrictionVisibility.ValueType = ...,
        verbose: bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: Literal["flight_id", b"flight_id", "restriction_mode", b"restriction_mode", "verbose", b"verbose"]) -> None: ...

@final
class FlightDetailsResponse(Message):
    DESCRIPTOR: Descriptor

    AIRCRAFT_INFO_FIELD_NUMBER: int
    SCHEDULE_INFO_FIELD_NUMBER: int
    FLIGHT_PROGRESS_FIELD_NUMBER: int
    FLIGHT_INFO_FIELD_NUMBER: int
    FLIGHT_PLAN_FIELD_NUMBER: int
    FLIGHT_TRAIL_LIST_FIELD_NUMBER: int
    POSITION_BUFFER_FIELD_NUMBER: int
    @property
    def aircraft_info(self) -> AircraftInfo: ...
    @property
    def schedule_info(self) -> ScheduleInfo: ...
    @property
    def flight_progress(self) -> FlightProgress: ...
    @property
    def flight_info(self) -> ExtendedFlightInfo: ...
    @property
    def flight_plan(self) -> FlightPlan: ...
    @property
    def flight_trail_list(self) -> RepeatedCompositeFieldContainer[TrailPoint]: ...
    @property
    def position_buffer(self) -> PositionBuffer: ...
    def __init__(
        self,
        *,
        aircraft_info: AircraftInfo | None = ...,
        schedule_info: ScheduleInfo | None = ...,
        flight_progress: FlightProgress | None = ...,
        flight_info: ExtendedFlightInfo | None = ...,
        flight_plan: FlightPlan | None = ...,
        flight_trail_list: Iterable[TrailPoint] | None = ...,
        position_buffer: PositionBuffer | None = ...,
    ) -> None: ...
    def HasField(self, field_name: Literal["aircraft_info", b"aircraft_info", "flight_info", b"flight_info", "flight_plan", b"flight_plan", "flight_progress", b"flight_progress", "position_buffer", b"position_buffer", "schedule_info", b"schedule_info"]) -> bool: ...
    def ClearField(self, field_name: Literal["aircraft_info", b"aircraft_info", "flight_info", b"flight_info", "flight_plan", b"flight_plan", "flight_progress", b"flight_progress", "flight_trail_list", b"flight_trail_list", "position_buffer", b"position_buffer", "schedule_info", b"schedule_info"]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

from builtins import (
    bool,
    float,
    int,
    str,
)
from collections.abc import (
    Iterable,
)
from google.protobuf.descriptor import (
    Descriptor,
    FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer,
)
from google.protobuf.message import (
    Message,
)
from typing import (
    Literal,
    final,
)

DESCRIPTOR: FileDescriptor

@final
class FlightSearchData(Message):
    DESCRIPTOR: Descriptor

    REG_FIELD_NUMBER: int
    SCHD_FROM_FIELD_NUMBER: int
    SCHD_TO_FIELD_NUMBER: int
    FLIGHT_FIELD_NUMBER: int
    OPERATOR_FIELD_NUMBER: int
    AC_TYPE_FIELD_NUMBER: int
    LAT_FIELD_NUMBER: int
    LON_FIELD_NUMBER: int
    CALLSIGN_FIELD_NUMBER: int
    ID_FIELD_NUMBER: int
    RESTRICTED_FIELD_NUMBER: int
    reg: str
    schd_from: str
    schd_to: str
    flight: str
    operator: str
    ac_type: str
    lat: float
    lon: float
    callsign: str
    id: int
    restricted: bool
    def __init__(
        self,
        *,
        reg: str = ...,
        schd_from: str = ...,
        schd_to: str = ...,
        flight: str = ...,
        operator: str = ...,
        ac_type: str = ...,
        lat: float = ...,
        lon: float = ...,
        callsign: str = ...,
        id: int = ...,
        restricted: bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: Literal["ac_type", b"ac_type", "callsign", b"callsign", "flight", b"flight", "id", b"id", "lat", b"lat", "lon", b"lon", "operator", b"operator", "reg", b"reg", "restricted", b"restricted", "schd_from", b"schd_from", "schd_to", b"schd_to"]) -> None: ...

@final
class FetchSearchIndexRequest(Message):
    DESCRIPTOR: Descriptor

    def __init__(
        self,
    ) -> None: ...

@final
class FetchSearchIndexResponse(Message):
    DESCRIPTOR: Descriptor

    FLIGHTS_LIST_FIELD_NUMBER: int
    @property
    def flights_list(self) -> RepeatedCompositeFieldContainer[FlightSearchData]: ...
    def __init__(
        self,
        *,
        flights_list: Iterable[FlightSearchData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: Literal["flights_list", b"flights_list"]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
NOTE: the definition in the web client is:
```
message LiveFlightsStatusResponse {
    repeated LiveFlightStatusData flights_map = 1;
}
```
but in reality it returns a wrapped `LiveFlightStatusData`.
the names `LiveFlightStatus`, `flight_id` and `data`
are non-official.
"""

from builtins import (
    bool,
    float,
    int,
)
from collections.abc import (
    Iterable,
)
from fr24.proto._common_pb2 import (
    Status,
)
from google.protobuf.descriptor import (
    Descriptor,
    FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer,
    RepeatedScalarFieldContainer,
)
from google.protobuf.message import (
    Message,
)
from typing import (
    Literal,
    final,
)

DESCRIPTOR: FileDescriptor

@final
class LiveFlightStatusData(Message):
    DESCRIPTOR: Descriptor

    LAT_FIELD_NUMBER: int
    LON_FIELD_NUMBER: int
    STATUS_FIELD_NUMBER: int
    SQUAWK_FIELD_NUMBER: int
    lat: float
    lon: float
    status: Status.ValueType
    squawk: int
    def __init__(
        self,
        *,
        lat: float = ...,
        lon: float = ...,
        status: Status.ValueType = ...,
        squawk: int = ...,
    ) -> None: ...
    def ClearField(self, field_name: Literal["lat", b"lat", "lon", b"lon", "squawk", b"squawk", "status", b"status"]) -> None: ...

@final
class LiveFlightsStatusRequest(Message):
    DESCRIPTOR: Descriptor

    FLIGHT_IDS_LIST_FIELD_NUMBER: int
    @property
    def flight_ids_list(self) -> RepeatedScalarFieldContainer[int]: ...
    def __init__(
        self,
        *,
        flight_ids_list: Iterable[int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: Literal["flight_ids_list", b"flight_ids_list"]) -> None: ...

@final
class LiveFlightStatus(Message):
    DESCRIPTOR: Descriptor

    FLIGHT_ID_FIELD_NUMBER: int
    DATA_FIELD_NUMBER: int
    flight_id: int
    @property
    def data(self) -> LiveFlightStatusData: ...
    def __init__(
        self,
        *,
        flight_id: int = ...,
        data: LiveFlightStatusData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: Literal["data", b"data"]) -> bool: ...
    def ClearField(self, field_name: Literal["data", b"data", "flight_id", b"flight_id"]) -> None: ...

@final
class LiveFlightsStatusResponse(Message):
    DESCRIPTOR: Descriptor

    FLIGHTS_MAP_FIELD_NUMBER: int
    @property
    def flights_map(self) -> RepeatedCompositeFieldContainer[LiveFlightStatus]: ...
    def __init__(
        self,
        *,
        flights_map: Iterable[LiveFlightStatus] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: Literal["flights_map", b"flights_map"]) -> None: ...
